@@ -931,338 +931,3 @@ int free_interval_dbfile(IntervalDBFile *db_file)
   return 0;
 }
 
-
-
-
-/* int save_text_file(char filestem[],char basestem[], */
-/* 		   char err_msg[],FILE *ofile) */
-/* { */
-/*   int i,n,ntop,div,nlists,nii,npad; */
-/*   char path[2048]; */
-/*   IntervalMap im; */
-/*   IntervalIndex ii; */
-/*   SublistHeader subheader; */
-/*   FILE *ifile=NULL; */
-
-/*   sprintf(path,"%s.size",filestem); /\* READ BASIC SIZE INFO*\/ */
-/*   ifile=fopen(path,"r"); /\* text file *\/ */
-/*   if (!ifile) */
-/*     goto unable_to_open_file; */
-/*   if (5!=fscanf(ifile,"%d %d %d %d %d",&n,&ntop,&div,&nlists,&nii)) */
-/*     goto fread_error_occurred; */
-/*   fclose(ifile); */
-/*   npad=ntop%div; */
-/*   if (npad>0) /\* PAD TO AN EXACT MULTIPLE OF div *\/ */
-/*     npad=ntop+(div-npad); */
-/*   else /\* AN EXACT MULTIPLE OF div, SO NO PADDING *\/ */
-/*     npad=ntop; */
-
-/*   if (fprintf(ofile,"SIZE\t%s\t%d %d %d %d %d\n", */
-/* 	      basestem,n,ntop,div,nlists,nii)<0) */
-/*     goto write_error_occurred; */
-
-/*   if (nii>0) { */
-/*     sprintf(path,"%s.index",filestem); /\* READ THE COMPACTED INDEX *\/ */
-/*     ifile=fopen(path,"rb"); /\* binary file *\/ */
-/*     if (!ifile) */
-/*       goto unable_to_open_file; */
-/*     for (i=0;i<nii;i++) { */
-/*       if (1!=fread(&ii,sizeof(IntervalIndex),1,ifile)) */
-/* 	goto fread_error_occurred; */
-/*       if (fprintf(ofile,"I %d %d\n",ii.start,ii.end)<0) */
-/* 	goto write_error_occurred; */
-/*     } */
-/*     fclose(ifile); */
-/*   } */
-
-/*   if(nlists>0){ */
-/*     sprintf(path,"%s.subhead",filestem); /\* READ THE SUBHEADER LIST *\/ */
-/*     ifile=fopen(path,"rb"); /\* binary file *\/ */
-/*     if (!ifile) */
-/*       goto unable_to_open_file; */
-/*     for (i=0;i<nlists;i++) { */
-/*       if (1!=fread(&subheader,sizeof(SublistHeader),1,ifile)) */
-/* 	goto fread_error_occurred; */
-/*       if (fprintf(ofile,"S %d %d\n",subheader.start,subheader.len)<0) */
-/* 	goto write_error_occurred; */
-/*       npad=subheader.start+subheader.len; */
-/*     } */
-/*     fclose(ifile); */
-/*   } */
-
-/*   if (npad>0) { */
-/*     sprintf(path,"%s.idb",filestem); /\* READ THE DATABASE *\/ */
-/*     ifile=fopen(path,"rb"); /\* binary file *\/ */
-/*     if (!ifile) */
-/*       goto unable_to_open_file; */
-/*     for (i=0;i<npad;i++) { */
-/*       if (1!=fread(&im,sizeof(IntervalMap),1,ifile)) */
-/* 	goto fread_error_occurred; */
-/*       if (fprintf(ofile,"M %d %d %d %d %d %d\n",im.start,im.end, */
-/* 		  im.target_id,im.target_start, */
-/* 		  im.target_end,im.sublist)<0) */
-/* 	goto write_error_occurred; */
-/*     } */
-/*     fclose(ifile); */
-/*   } */
-/*   return 0; /\* INDICATES NO ERROR OCCURRED *\/ */
-/*  unable_to_open_file: */
-/*   if (err_msg) */
-/*     sprintf(err_msg,"unable to open file %s",path); */
-/*   return -1; */
-/*  fread_error_occurred: */
-/*   if (err_msg) */
-/*     sprintf(err_msg,"error or EOF reading file %s",path); */
-/*   return -1; */
-/*  write_error_occurred: */
-/*   if (err_msg) */
-/*     sprintf(err_msg,"error writing output file! out of disk space?"); */
-/*   return -1; */
-/* } */
-
-
-
-/* int text_file_to_binaries(FILE *infile,char buildpath[],char err_msg[]) */
-/* { */
-/*   int i,n,ntop,div,nlists,nii,npad; */
-/*   char path[2048],line[32768],filestem[2048]; */
-/*   IntervalMap im; */
-/*   IntervalIndex ii; */
-/*   SublistHeader subheader; */
-/*   FILE *ifile=NULL; */
-
-/*   if (NULL==fgets(line,32767,infile)) */
-/*     goto fread_error_occurred; */
-/*   if (6!=sscanf(line,"SIZE\t%s\t%d %d %d %d %d", */
-/* 		filestem,&n,&ntop,&div,&nlists,&nii)) */
-/*     goto fread_error_occurred; */
-/*   sprintf(path,"%s%s.size",buildpath,filestem); /\* SAVE BASIC SIZE INFO*\/ */
-/*   ifile=fopen(path,"w"); /\* text file *\/ */
-/*   if (!ifile) */
-/*     goto unable_to_open_file; */
-/*   if (fprintf(ifile,"%d %d %d %d %d\n",n,ntop,div,nlists,nii)<0) */
-/*     goto write_error_occurred; */
-/*   fclose(ifile); */
-/*   npad=ntop%div; */
-/*   if (npad>0) /\* PAD TO AN EXACT MULTIPLE OF div *\/ */
-/*     npad=ntop+(div-npad); */
-/*   else /\* AN EXACT MULTIPLE OF div, SO NO PADDING *\/ */
-/*     npad=ntop; */
-
-/*   if (nii>0) { */
-/*     sprintf(path,"%s%s.index",buildpath,filestem); /\* SAVE INDEX INFO*\/ */
-/*     ifile=fopen(path,"wb"); /\* binary file *\/ */
-/*     if (!ifile) */
-/*       goto unable_to_open_file; */
-/*     for (i=0;i<nii;i++) { */
-/*       if (NULL==fgets(line,32767,infile)) */
-/* 	goto fread_error_occurred; */
-/*       if (2!=sscanf(line,"I %d %d",&(ii.start),&(ii.end))) */
-/* 	goto fread_error_occurred; */
-/*       if (1!=fwrite(&ii,sizeof(IntervalIndex),1,ifile)) */
-/* 	goto write_error_occurred; */
-/*     } */
-/*     fclose(ifile); */
-/*   } */
-
-/*   if(nlists>0){ */
-/*     sprintf(path,"%s%s.subhead",buildpath,filestem); /\* SAVE THE SUBHEADER LIST *\/ */
-/*     ifile=fopen(path,"wb"); /\* binary file *\/ */
-/*     if (!ifile) */
-/*       goto unable_to_open_file; */
-/*     for (i=0;i<nlists;i++) { */
-/*       if (NULL==fgets(line,32767,infile)) */
-/* 	goto fread_error_occurred; */
-/*       if (2!=sscanf(line,"S %d %d",&(subheader.start),&(subheader.len))) */
-/* 	goto fread_error_occurred; */
-/*       if (1!=fwrite(&subheader,sizeof(SublistHeader),1,ifile)) */
-/* 	goto write_error_occurred; */
-/*       npad=subheader.start+subheader.len; */
-/*     } */
-/*     fclose(ifile); */
-/*   } */
-
-/* sprintf(path,"%s%s.idb",buildpath,filestem); /\* SAVE THE ACTUAL INTERVAL DB*\/ */
-/* ifile=fopen(path,"wb"); /\* binary file *\/ */
-/* if (!ifile) */
-/*   goto unable_to_open_file; */
-/* for (i=0;i<npad;i++) { */
-/*   if (NULL==fgets(line,32767,infile)) */
-/*     goto fread_error_occurred; */
-/*   if (6!=sscanf(line,"M %d %d %d %d %d %d",&(im.start),&(im.end), */
-/* 	  &(im.target_id),&(im.target_start), */
-/* 	  &(im.target_end),&(im.sublist))) */
-/*     goto fread_error_occurred; */
-/*   if (1!=fwrite(&im,sizeof(IntervalMap),1,ifile)) */
-/*     goto write_error_occurred; */
-/* } */
-/* fclose(ifile); */
-
-/*   return 0; /\* INDICATES NO ERROR OCCURRED *\/ */
-/*  unable_to_open_file: */
-/*   if (err_msg) */
-/*     sprintf(err_msg,"unable to open file %s",path); */
-/*   return -1; */
-/*  fread_error_occurred: */
-/*   if (err_msg) */
-/*     sprintf(err_msg,"error or EOF reading input file"); */
-/*   return -1; */
-/*  write_error_occurred: */
-/*   if (err_msg) */
-/*     sprintf(err_msg,"error writing file %s! out of disk space?", */
-/* 	    path); */
-/*   return -1; */
-/* } */
-
-
-
-/* int main(int argc, char **argv) { */
-
-/*   int interval_map_size = 1024; */
-
-/*   IntervalMap *im; */
-/*   int len = 10000000; */
-/*   SublistHeader *sl; */
-/*   int *p_n = malloc(sizeof *p_n); */
-/*   int *p_nlists = malloc(sizeof *p_nlists); */
-/*   int *nhits = malloc(sizeof *nhits); */
-
-/*   FILE *ifp; */
-
-/*   ifp = fopen("../test.csv", "r"); */
-
-/*   struct timeval  tv1, tv2; */
-/*   gettimeofday(&tv1, NULL); */
-/*   im = read_intervals(len, ifp); */
-/*   gettimeofday(&tv2, NULL); */
-/*   printf ("Total time = %f seconds\n", */
-/*           (double) (tv2.tv_usec - tv1.tv_usec) / 1000000 + */
-/*           (double) (tv2.tv_sec - tv1.tv_sec)); */
-
-/*   gettimeofday(&tv1, NULL); */
-/*   sl = build_nested_list(im, len, p_n, p_nlists); */
-/*   gettimeofday(&tv2, NULL); */
-/*   printf ("Total time = %f seconds\n", */
-/*           (double) (tv2.tv_usec - tv1.tv_usec) / 1000000 + */
-/*           (double) (tv2.tv_sec - tv1.tv_sec)); */
-/*   IntervalIterator *it = interval_iterator_alloc(); */
-
-/*   IntervalMap im_buf[interval_map_size]; */
-
-/*   printf("*p_nlists %d\n", *p_nlists); */
-/*   find_intervals(it, 0, 500, im, len, sl, *p_nlists, im_buf, interval_map_size, nhits, &it); */
-/*   printf("*nhits %d\n", *nhits); */
-
-/*   int i; */
-/*   for (i = 0; i < *nhits; i++){ */
-/*     printf("Start %d End %d Id %d\n", im_buf[i].target_start, im_buf[i].target_end, im_buf[i].target_id); */
-/*   } */
-
-/*   free(p_n); */
-/*   free(p_nlists); */
-/*   free(nhits); */
-
-/* } */
-
-
-/* int find_k_next(int start, int end, */
-/*                 IntervalMap im[], int n, */
-/*                 SublistHeader subheader[], int nlists, */
-/*                 IntervalMap buf[], int ktofind, */
-/*                 int *p_nreturn) */
-/* { */
-/*   IntervalIterator *it=NULL,*it2=NULL; */
-/*   int nfound=0,j,k; */
-/*   /\* IntervalMap *results = interval_map_alloc(ktofind); *\/ */
-
-/*   /\* CALLOC(it,1,IntervalIterator); *\/ */
-
-/*   if (it->n == 0) { /\* DEFAULT: SEARCH THE TOP NESTED LIST *\/ */
-/*     it->n=n; */
-/*     it->i=find_overlap_start(start,end,im,n); */
-/*   } */
-
-/*   do { */
-/*     while (it->i>=0 && it->i<it->n && (nfound < ktofind)) { */
-/*       if (!HAS_OVERLAP_POSITIVE(im[it->i],start,end)) { */
-/*         buf[nfound] = im[it->i]; /\*SAVE THIS HIT TO BUFFER *\/ */
-/*         nfound++; */
-/*       } */
-/*       k=im[it->i].sublist; /\* GET SUBLIST OF i IF ANY *\/ */
-/*       it->i++; /\* ADVANCE TO NEXT INTERVAL *\/ */
-/*       if (k>=0 && (j=find_suboverlap_start(start,end,k,im,subheader))>=0) { */
-/*         PUSH_ITERATOR_STACK(it,it2,IntervalIterator); /\* RECURSE TO SUBLIST *\/ */
-/*         it2->i = j; /\* START OF OVERLAPPING HITS IN THIS SUBLIST *\/ */
-/*         it2->n = subheader[k].start+subheader[k].len; /\* END OF SUBLIST *\/ */
-/*         it=it2; /\* PUSH THE ITERATOR STACK *\/ */
-/*       } */
-/*     } */
-/*   } while (POP_ITERATOR_STACK(it));  /\* IF STACK EXHAUSTED, EXIT *\/ */
-/*   free_interval_iterator(it); /\* takes care of the whole stack *\/ */
-/*   it=NULL;  /\* ITERATOR IS EXHAUSTED *\/ */
-
-/*   *p_nreturn=nfound; /\* #INTERVALS FOUND IN THIS PASS *\/ */
-/* } */
-
-
-int find_intervals_stack(int start_stack[], int end_stack[], int sp, int start,
-                                int end, IntervalMap im[], int n,
-                                SublistHeader subheader[], IntervalMap buf[],
-                                int *p_nreturn)
-{
-  /* IntervalIterator *it=NULL,*it2=NULL; */
-  /* printf("In very beginning!\n"); */
-  /* return 0; */
-  int nfound = 0, j, k;
-  /* printf("j: %d, sp: %d, start_stack[sp]: %d", 0, sp, sp); */
-
-  /* if (sp == 0) { */
-  clock_t t;
-  t = clock();
-  j = find_overlap_start(start,end,im,n);
-  t = clock() - t;
-  double time_taken = ((double)t)/CLOCKS_PER_SEC; // in seconds
-  printf("fun() took %f seconds to execute \n", time_taken);
-  start_stack[sp] = j;
-  end_stack[sp] = n;
-  /* } */
-
-  /* printf("We are before loop\n"); */
-  /* printf("start, end: %d, %d", start_stack[sp], end_stack[sp]); */
-
-  /* fflush(stdout); */
-
-  while (sp >= 0) {
-    /* printf("Outer loop. sp: %d, st: %d, end: %d\n", sp, start_stack[sp], end_stack[sp]); */
-    /* fflush(stdout); */
-    while (start_stack[sp] >= 0 && start_stack[sp] < end_stack[sp] && \
-           HAS_OVERLAP_POSITIVE(im[start_stack[sp]], start, end)) {
-      /* printf("Inner loop. sp: %d\n", start_stack[sp]); */
-      /* printf("Interval added: %d, %d, %d\n", im[start_stack[sp]].start, im[start_stack[sp]].end, im[start_stack[sp]].target_id); */
-      memcpy(buf+nfound, im + start_stack[sp], sizeof(IntervalMap)); /*SAVE THIS HIT TO BUFFER */
-
-      nfound++;
-      k=im[sp].sublist; /* GET SUBLIST OF i IF ANY */
-
-      start_stack[sp++]++; /* ADVANCE TO NEXT INTERVAL */
-      if (k>=0 && (j=find_suboverlap_start(start,end,k,im,subheader))>=0) {
-        sp++;
-        start_stack[sp] = j;
-        end_stack[sp] = subheader[k].start + subheader[k].len; /* END OF SUBLIST */
-      }
-
-      if (nfound>=1024){ /* FILLED THE BUFFER, RETURN THE RESULTS SO FAR */
-        goto finally_return_result;
-      }
-    }
-
-    sp--;
-
-  }
-
- finally_return_result:
-
-    *p_nreturn = nfound; /* #INTERVALS FOUND IN THIS PASS */
-
-  return sp;
-}
